@@ -14,8 +14,6 @@
 #    under the License.
 
 
-import mock
-
 import seamicroclient.client
 from seamicroclient.tests import utils
 import seamicroclient.v2.client
@@ -33,10 +31,3 @@ class ClientTest(utils.TestCase):
     def test_get_client_class_v2(self):
         output = seamicroclient.client.get_client_class('2')
         self.assertEqual(output, seamicroclient.v2.client.Client)
-
-    @mock.patch.object(seamicroclient.client.HTTPClient, 'authenticate')
-    def test_authenticate_call_v2(self, mock_authenticate):
-        cs = seamicroclient.v2.client.Client("user", "password",
-                                             auth_url="foo/v2")
-        cs.authenticate()
-        self.assertTrue(mock_authenticate.called)
